import{Q as s,aQ as m,c as n,aj as e,Z as l,B as c,S as u,a4 as f}from"./index-OVJFSuO1.js";import{I as h}from"./ItemsListing-CdfNc-Lx.js";import"./MediaItemThumb-BLYBgn8B.js";import"./ProviderIcon.vue_vue_type_style_index_0_lang-D-4kgxN_.js";import"./VChip-BLxgh-kC.js";import"./VBtn-BHI_gFkG.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./ListItem-WUYGjpIG.js";import"./VCheckbox-15dKieJn.js";import"./VCheckboxBtn-4SSjCBwD.js";import"./PanelviewItemCompact-BmHmF_Ad.js";import"./VSpacer-RhrXGRx8.js";/* empty css              */import"./Container-DrUgBwRd.js";import"./VContainer-BshuJqQR.js";import"./Toolbar-DavOcuNq.js";import"./VToolbar-LfcovWTQ.js";import"./VTextField-8x9Z_kY_.js";import"./VInfiniteScroll-BwSEmJTY.js";import"./layout-DIUY8qom.js";import"./VRow-B7GLjig6.js";import"./VVirtualScroll-Drag7IKh.js";import"./VAlert-DfyW_lDT.js";const F=s({__name:"BrowseView",props:{path:{}},setup(a){const t=a,{t:o}=m(),i=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),p=async function(r){return await f.browse(t.path)};return(r,w)=>(u(),l("section",null,[c(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":p,"sort-keys":["original","name","name_desc"],title:i.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{F as default};
